[![codecov](https://codecov.io/gh/zachspar/fred-py-api/branch/main/graph/badge.svg?token=BG1948D8Y7)](https://codecov.io/gh/zachspar/fred-py-api)

# Fred Python API
A fully-featured FRED Python Wrapper.

## Documentation:
 - [fred-py-api Docs](https://github.com/zachspar/fred-py-api/wiki)

### FRED References:
 - [Create an API Key Here](https://fredaccount.stlouisfed.org/apikey)
 - [API Documentation](https://fred.stlouisfed.org/docs/api/fred/)

